@@ -2,7 +2,7 @@
  *  cache-file.c
  *  mod_musicindex
  *
- *  $Id: cache-file.c 905 2010-01-08 13:16:43Z varenet $
+ *  $Id: cache-file.c 934 2010-05-29 23:13:55Z varenet $
  *
  *  Created by Thibaut VARENE on Wed Feb 23 2005.
  *  Copyright (c) 2003-2007,2009-2010 Thibaut VARENE
@@ -18,8 +18,8 @@
  * Flat file cache management subsystem.
  *
  * @author Thibaut Varene
- * @version $Revision: 905 $
- * @date 2003-2009
+ * @version $Revision: 934 $
+ * @date 2003-2010
  *
  * @warning 'errno' seems not to be seen as volatile by the compiler, therefore we
  *	cannot do "if(mkdir(foo) && errno == EEXIST)" for instance.
@@ -220,7 +220,7 @@ static void file_cache_remove_dir(request_rec *r, DIR *cachedir, const char *con
 	struct stat	origdirstat;
 	const char 	*origdir = NULL;
 
-	fchdir(dirfd(cachedir));			/* on se place dans le repertoire de cache. XXX Pas de test ici, tout est verifie avant (en principe). */
+	fchdir(dirfd(cachedir));			/* on se place dans le repertoire de cache. XXX Pas de test, au pire fail sur readdir() */
 	while ((cachedirent = readdir(cachedir))) {	/* on parcourt le repertoire */
 		if (ISDOT(cachedirent->d_name))		/* We'd rather avoid trying to remove the whole filesystem... */
 			continue;
@@ -255,28 +255,6 @@ static void file_cache_remove_dir(request_rec *r, DIR *cachedir, const char *con
 	return;
 }
 
-/**
- * Initializes flat file cache subsystem.
- *
- * Basically we do nothing more here than creating the root cache folder.
- *
- * @param s Apache server_rec struct to handle log writings.
- * @param cache_setup configuration string in which the path to the cache root can be found.
- *
- * @return CA_OK on succes, CA_FATAL otherwise.
- */
-static short file_cache_init(server_rec *s, const char *const cache_setup)
-{
-	if (chdir("/") || file_cache_make_dir(NULL, cache_setup + 1))	/* since we've chdir'd, we send the path without the leading '/' */
-		goto error_out;
-
-	return CA_OK;
-
-error_out:
-	mi_serror("Cannot setup file cache!");
-	return CA_FATAL;
-}
-
 /**
  * Checks if a directory already exists in the cache.
  *
@@ -304,7 +282,7 @@ static void* cache_file_opendir(request_rec *r, mu_pack *const pack, const mu_co
 	DIR		*cachedir = NULL;
 	struct stat	cachedirstat, dirstat;
 
-	if (!path)
+	if (!path || !conf->cache_setup)
 		return NULL;
 
 	/* Bear in mind we're chdir'd from now on. */
@@ -374,7 +352,8 @@ static mu_ent *file_make_cache_entry(request_rec *r, apr_pool_t *pool, FILE *con
 	struct mi_data_buffer	*data_buffer = NULL;
 
 	/* Bear in mind we're chdir'd from now on. */
-	chdir((char *)(conf->cache_setup));
+	if (unlikely(chdir((char *)(conf->cache_setup))))
+		return p;
 
 	/* Actually check for the file in the cache, open it if possible.
 	 * "+ 1" offset to suppress leading '/'.
@@ -476,7 +455,8 @@ static void cache_file_write(request_rec *r, const mu_ent *const p, const mu_con
 	if (p->filetype < 0)
 		return;
 	
-	chdir((char *)conf->cache_setup);	/* Par securite on se re-chdir(). XXX Considere sans echec */
+	if (chdir((char *)conf->cache_setup))
+		return;
 	
 	/* Dev note: O_EXLOCK is BSD specific. */
 	fdesc = open(names->filename + 1, O_WRONLY|O_NONBLOCK|O_CREAT, S_IRUSR|S_IWUSR);
@@ -518,29 +498,44 @@ error_out:
 }
 
 static const cache_backend cache_backend_file = {
-	cache_file_opendir,
-	NULL,
-	NULL,
-	file_make_cache_entry,
-	cache_file_write
+	.opendir =	cache_file_opendir,
+	.readdir =	NULL,
+	.closedir =	NULL,
+	.make_entry =	file_make_cache_entry,
+	.write =	cache_file_write,
+	.prologue =	NULL,
+	.epilogue =	NULL,
 };
 
 int cache_file_setup(cmd_parms *cmd, const char *const setup_string, mu_config *const conf)
 {
 	server_rec *s = cmd->server;
 	static const char biniou[] = "file://";
+	int ret = 1;
 
 	if (strncmp(biniou, setup_string, 7) == 0) {
-		conf->cache_setup = apr_pstrdup(cmd->pool, setup_string+6);
-		if (!conf->cache_setup)
+		ret = -1;
+		const char *restrict csetup = apr_pstrdup(cmd->pool, setup_string+6);
+		if (!csetup)
 			goto exit;
-		if (chdir((char *)(conf->cache_setup))) {
+#if 0	/* this is never happening since we check against "file://" */
+		if (csetup[0] != '/') {
+			/* for now we only work with absolute paths */
+			mi_serror("Non absolute cache directory path: %s", csetup);
+			goto exit;
+		}
+#endif
+		if ( (access(csetup, X_OK|W_OK)) || (chdir((char *)(csetup))) ) {
 			mi_serror("%s", strerror(errno));
 			goto exit;
 		}
+		conf->cache_setup = csetup;
 		conf->cache = &cache_backend_file;
-		return file_cache_init(s, conf->cache_setup);
+		ret = 0;
 	}
+	
 exit:
-	return 1;
+	if (-1 == ret)
+		mi_serror("Error setting up file cache!");
+	return ret;
 }
