@@ -2,7 +2,7 @@
  *  cache-mysql.c
  *  mod_musicindex
  *
- *  $Id: cache-mysql.c 943 2010-06-06 17:39:54Z varenet $
+ *  $Id: cache-mysql.c 947 2010-06-07 11:06:01Z varenet $
  *
  *  Created by Thibaut VARENE on Tue Feb 22 2005.
  *  Copyright (c) 2005,2007,2009-2010 Thibaut VARENE
@@ -49,7 +49,7 @@
  * @todo clean error handler when data corruption happens.
  *
  * @author Thibaut Varene
- * @version $Revision: 943 $
+ * @version $Revision: 947 $
  * @date 2005,2007,2009-2010
  */
 
@@ -146,7 +146,7 @@ mysql_cache_new_ent(apr_pool_t *pool, MYSQL_ROW mysql_row)
  *	will be under module's control
  *
  * @param s Apache server_rec struct to handle log writings.
- * @param cache_setup configuration string in which the path to the cache root can be found.
+ * @param setup_string configuration string in which the path to the cache root can be found.
  *
  * @return 0 on succes, -1 otherwise.
  */
@@ -190,7 +190,7 @@ mysql_cache_init(server_rec *s, const char *const setup_string)
 			"`flags` TINYINT UNSIGNED NOT NULL,"
 			"`track` TINYINT UNSIGNED NOT NULL,"
 			"`posn` TINYINT UNSIGNED NOT NULL,"
-			"`cvers` TINYINT UNSIGNED NOT NULL,"
+			"`cvers` TINYINT UNSIGNED NOT NULL," /* XXX this should be useless since we trash the whole cache on version bums... */
 			"`date` SMALLINT UNSIGNED NOT NULL,"
 			"`freq` SMALLINT UNSIGNED NOT NULL,"
 			"`length` SMALLINT UNSIGNED NOT NULL,"
