@@ -2,11 +2,11 @@
  *  html.c
  *  mod_musicindex
  *
- *  $Id: html.c 900 2009-12-06 21:48:19Z varenet $
+ *  $Id: html.c 927 2010-05-26 13:13:59Z varenet $
  *
  *  Created by Thibaut VARENE on Thu Mar 20 2003.
  *  Copyright (c) 2003-2006 Regis BOUDIN
- *  Copyright (c) 2003-2009 Thibaut VARENE
+ *  Copyright (c) 2003-2010 Thibaut VARENE
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License version 2.1,
@@ -20,8 +20,8 @@
  *
  * @author Regis Boudin
  * @author Thibaut Varene
- * @version $Revision: 900 $
- * @date 2003-2009
+ * @version $Revision: 927 $
+ * @date 2003-2010
  *
  * That file groups all functions related to HTML and assimilated
  * generation, that is to say functions that are used to
@@ -309,13 +309,13 @@ list_songs(request_rec *r, const mu_pack *const pack, const mu_config *const con
 					ap_rprintf(r, "   <td class=\"Album\">%s</td>\n", q->album ? ap_escape_html(r->pool, q->album) : "");
 					break;
 				case SB_FILETYPE:
-						ap_rvputs(r, "   <td class=\"Filetype\">", filetype[q->filetype % FT_MAX].nametype, "</td>\n", NULL);
+					ap_rvputs(r, "   <td class=\"Filetype\">", filetype[q->filetype % FT_MAX].nametype, "</td>\n", NULL);
 					break;
 				case SB_GENRE:
 					ap_rprintf(r, "   <td class=\"Genre\">%s</td>\n", q->genre ? ap_escape_html(r->pool, q->genre) : "");
 					break;
 				case SB_SIZE:
-					ap_rprintf(r, "   <td class=\"Size\"><acronym title=\"MB\">%ld.%ld</acronym></td>\n", q->size>>20, (q->size>>10)%1024/100);
+					ap_rprintf(r, "   <td class=\"Size\"><acronym title=\"MB\">%ld.%ld</acronym></td>\n", q->size>>20, (((q->size>>10)%1024)*10)>>10);	/* get kB residue *10/1024 (instead of /102.4) */ 
 					break;
 				case SB_FILENAME:
 					ap_rvputs(r, "   <td class=\"Filename\">", ap_escape_html(r->pool, q->filename), "</td>\n", NULL);
@@ -341,7 +341,7 @@ list_songs(request_rec *r, const mu_pack *const pack, const mu_config *const con
 	
 	ap_rprintf(r, "%s: %ld:%.2ld:%.2ld - %s: %ld.%ld MB</th>\n  </tr>\n",
 			   _("Total Length"), tlength / 60 / 60, tlength / 60 % 60, tlength % 60,
-			   _("Total Size"), tsize >> 20, (tsize >> 10) % 1024 / 100);
+			   _("Total Size"), tsize >> 20, (((tsize >> 10) % 1024) * 10) >> 10);
 	
 	return fld;
 }
@@ -1114,14 +1114,14 @@ void send_foot(request_rec *r, const mu_config *const conf, const STRUCTTV *tvbe
 			 "    alt=\"Valid CSS!\" height=\"31\" width=\"88\" />\n"
 			 "  </a>\n", r);
 	/* Valid RSS */
-	if (subreq && !access(apr_pstrcat(r->pool, subreq->filename, "/loveRss.gif", NULL), R_OK)) {
-		icn = apr_pstrcat(r->pool, conf->directory, "/loveRss.gif", NULL);
-		ap_rvputs(r, "  <img src=\"", icn, "\" alt=\"Valid RSS!\" />\n", NULL);
+	if (subreq && !access(apr_pstrcat(r->pool, subreq->filename, "/valid-rss.png", NULL), R_OK)) {
+		icn = apr_pstrcat(r->pool, conf->directory, "/valid-rss.png", NULL);
+		ap_rvputs(r, "  <img src=\"", icn, "\" alt=\"[Valid RSS]\" title=\"Validate my RSS feed\" />\n", NULL);
 	}
 	else
-		ap_rputs("  <a href=\"http://rss.scripting.com/\">\n"
-			 "   <img src=\"http://cyber.law.harvard.edu/blogs/gems/tech/loveRss.gif\"\n"
-			 "    width=\"65\" height=\"59\" alt=\"Valid RSS feed.\" />\n"
+		ap_rputs("  <a href=\"http://validator.w3.org/feed/check.cgi?uri=referer\">\n"
+			 "   <img src=\"http://validator.w3.org/feed/images/valid-rss.png\"\n"
+			 "    alt=\"[Valid RSS]\" title=\"Validate my RSS feed\" />\n"
 			 "  </a>\n", r);
 	ap_rputs(" </div>\n", r);
 
