@@ -2,7 +2,7 @@
  *  mod_musicindex.c
  *  mod_musicindex
  *
- *  $Id: mod_musicindex.c 934 2010-05-29 23:13:55Z varenet $
+ *  $Id: mod_musicindex.c 949 2010-09-02 11:14:32Z varenet $
  *
  *  Created by Regis BOUDIN on Sat Dec 28 2002.
  *  Copyright (c) 2002-2006 Regis BOUDIN
@@ -129,7 +129,7 @@
  * This file is the core of the module. It contains Apache's mandatory stuff.
  *
  * @author Regis Boudin
- * @version $Revision: 934 $
+ * @version $Revision: 949 $
  * @date 2002-2008
  * @date 2010
  *
@@ -344,7 +344,8 @@ static int handle_musicindex(request_rec *r)
 		strcat(content_disposition, "filename=\"playlist.m3u\"");
 
 		ap_set_content_type(r, "audio/x-mpegurl");
-		apr_table_setn(r->headers_out, "Content-Disposition", content_disposition);
+		apr_table_set(r->headers_out, "Content-Disposition", content_disposition);
+		/* apr_table_set() duplicates keys and values, this is necessary here */
 	}
 #ifdef ENABLE_OUTPUT_ARCHIVE
 	else if (conf->options & MI_TARBALL) {
