@@ -2,7 +2,7 @@
  *  playlist-mp3.c
  *  mod_musicindex
  *
- *  $Id: playlist-mp3.c 899 2009-12-04 13:55:29Z varenet $
+ *  $Id: playlist-mp3.c 935 2010-05-29 23:27:24Z varenet $
  *
  *  Created by Regis BOUDIN on Thu Jan 22 2004.
  *  Copyright (c) 2003-2004 Regis BOUDIN
@@ -20,7 +20,7 @@
  *
  * @author Regis Boudin
  * @author Thibaut Varene
- * @version $Revision: 899 $
+ * @version $Revision: 935 $
  * @date 2003-2009
  *
  * This file contains everything needed to produce music entries from
@@ -181,7 +181,7 @@ fail:
 static inline short mpg123_mp3_ext_check(const char *const filename)
 {
 	const char *const ext = strrchr(filename, '.');
-	if (ext	&& (!strncasecmp(ext, ".mp2", 4) || !strncasecmp(ext, ".mp3", 4)))
+	if (ext	&& (!strncasecmp(ext, ".mp3", 4) || !strncasecmp(ext, ".mp2", 4)))
 		return FALSE;
 	return TRUE;
 }
@@ -215,7 +215,7 @@ static id3_utf8_t *utf8_id3tag_findframe(struct id3_tag *tag, const char *const
 		nstrings = id3_field_getnstrings(field);
 		for (i = 0; i < nstrings; ++i) {
 			if ((ucs4 = id3_field_getstrings(field, i))) {
-				if (frameid == ID3_FRAME_GENRE) {
+				if (strcmp(frameid, ID3_FRAME_GENRE) == 0) {
 					/* Some encoders encaps id nb in brackets and the
 					lib doesn't handle this properly. This is ugly */
 					if ((ucs4[0] == '(') && (isdigit(ucs4[1]))) {
@@ -247,7 +247,6 @@ static id3_utf8_t *utf8_id3tag_findframe(struct id3_tag *tag, const char *const
  * @param r Apache request_rec struct to handle log writings (debugging)
  *
  * @bug Some VBR files are reported as "bitrate: 0".
- * @todo use iofile accessors from libid3tag to avoid opening the file separately
  *
  * @return When possible, struct mu_ent correctly set up, file stream closed.
  */
